==> magento-ece-tools-2002.0.18.zip: src/Test/Unit/DB/Data/RelationshipConnectionFactoryTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\MagentoCloud\Test\Unit\DB\Data;

use Magento\MagentoCloud\Config\Environment;
use Magento\MagentoCloud\DB\Data\RelationshipConnectionFactory;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

/**
 * @inheritdoc
 */
class RelationshipConnectionFactoryTest extends TestCase
{
    /**
     * @var RelationshipConnectionFactory
     */
    private $factory;

    /**
     * @var Environment|MockObject
     */
    private $environmentMock;

    /**
     * @inheritdoc
     */
    protected function setUp()
    {
        $this->environmentMock = $this->createMock(Environment::class);

        $this->factory = new RelationshipConnectionFactory(
            $this->environmentMock
        );
    }

    public function testCreateMain()
    {
        $this->environmentMock->expects($this->once())
            ->method('getRelationship')
            ->with('database')
            ->willReturn([[]]);

        $this->factory->create(RelationshipConnectionFactory::CONNECTION_MAIN);
    }

    public function testCreateSlave()
    {
        $this->environmentMock->expects($this->once())
            ->method('getRelationship')
            ->with('database-slave')
            ->willReturn([[]]);

        $this->factory->create(RelationshipConnectionFactory::CONNECTION_SLAVE);
    }

    /**
     * @expectedException \RuntimeException
     * @expectedExceptionMessage Connection with type dummy doesn't exist
     */
    public function testCreateWithException()
    {
        $this->factory->create('dummy');
    }
}

==> magento-ece-tools-2002.0.21.zip: src/Test/Unit/DB/Data/RelationshipConnectionFactoryTest.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Magento\MagentoCloud\Test\Unit\DB\Data;

use Magento\MagentoCloud\DB\Data\RelationshipConnectionFactory;
use Magento\MagentoCloud\Service\Database;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

/**
 * @inheritdoc
 */
class RelationshipConnectionFactoryTest extends TestCase
{
    /**
     * @var RelationshipConnectionFactory
     */
    private $factory;

    /**
     * @var Database|MockObject
     */
    private $databaseMock;

    /**
     * @inheritdoc
     */
    protected function setUp()
    {
        $this->databaseMock = $this->createMock(Database::class);

        $this->factory = new RelationshipConnectionFactory(
            $this->databaseMock
        );
    }

    public function testCreateMain()
    {
        $this->databaseMock->expects($this->once())
            ->method('getConfiguration')
            ->willReturn([]);

        $this->factory->create(RelationshipConnectionFactory::CONNECTION_MAIN);
    }

    public function testCreateSlave()
    {
        $this->databaseMock->expects($this->once())
            ->method('getSlaveConfiguration')
            ->willReturn([]);

        $this->factory->create(RelationshipConnectionFactory::CONNECTION_SLAVE);
    }

    /**
     * @expectedException \RuntimeException
     * @expectedExceptionMessage Connection with type dummy doesn't exist
     */
    public function testCreateWithException()
    {
        $this->factory->create('dummy');
    }
}
